Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(508)

Unified Diff: components/precache/content/precache_manager.cc

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/browser_sync/test_profile_sync_service.cc ('k') | components/sync/driver/about_sync_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/precache/content/precache_manager.cc
diff --git a/components/precache/content/precache_manager.cc b/components/precache/content/precache_manager.cc
index f4333c12d64e9b02779ca6a8de304a99f2e8bcf5..327fa2b6b83ceafdd748f932467358cb30803ee7 100644
--- a/components/precache/content/precache_manager.cc
+++ b/components/precache/content/precache_manager.cc
@@ -99,7 +99,7 @@ bool PrecacheManager::IsPrecachingAllowed() const {
}
PrecacheManager::AllowedType PrecacheManager::PrecachingAllowed() const {
- if (!(sync_service_ && sync_service_->IsBackendInitialized()))
+ if (!(sync_service_ && sync_service_->IsEngineInitialized()))
return AllowedType::PENDING;
// SyncService delegates to SyncPrefs, which must be called on the UI thread.
@@ -182,7 +182,7 @@ void PrecacheManager::OnGetUnfinishedWorkDone(
}
} else {
if (PrecachingAllowed() != AllowedType::PENDING) {
// We are not waiting on the sync backend to be initialized. The user
// either is not in the field trial, or does not have sync enabled.
// Pretend that precaching started, so that the PrecacheServiceLauncher
// doesn't try to start it again.
@@ -182,7 +182,7 @@ void PrecacheManager::OnGetUnfinishedWorkDone(
} else {
if (PrecachingAllowed() != AllowedType::PENDING) {
- // We are not waiting on the sync backend to be initialized. The user
+ // We are not waiting on the sync engine to be initialized. The user
// either is not in the field trial, or does not have sync enabled.
// Pretend that precaching started, so that the PrecacheServiceLauncher
« no previous file with comments | « components/browser_sync/test_profile_sync_service.cc ('k') | components/sync/driver/about_sync_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698